Module protocol

Module protocol 

Modules

context

Structs

Context
Additional context to be passed to the credentials helper.
Outcome
The outcome of the credentials top-level functions to obtain a complete identity.

Enums

Error
The error returned top-level credential functions.

Functions

helper_outcome_to_result
Convert the outcome of a helper invocation to a helper result, assuring that the identity is complete in the process.

Type Aliases

Result
The Result type used in credentials top-level functions to obtain a complete identity.